@@ -52,7 +52,8 @@
 #' is a list of `Dataset`s (because there should be few `Dataset`s in the list
 #' and their `Schema`s are already in memory).
 #' @param ... additional arguments passed to `dataset_factory()` when
-#' `sources` is a file path, otherwise ignored.
+#' `sources` is a file path, otherwise ignored. These may include "format" to
+#' indicate the file format, or other format-specific options.
 #' @return A [Dataset] R6 object. Use `dplyr` methods on it to query the data,
 #' or call [`$NewScan()`][Scanner] to construct a query directly.
 #' @export
@@ -122,9 +123,8 @@ open_dataset <- function(sources,
 #' takes the following arguments:
 #' * `filesystem`: A [FileSystem]
 #' * `selector`: A [FileSelector]
-#' * `format`: A string identifier of the format of the files in `path`.
-#'   Currently "parquet" and "ipc"/"arrow"/"feather" (aliases for each other)
-#'   are supported. For Feather, only version 2 files are supported.
+#' * `format`: A [FileFormat]
+#' * `partitioning`: Either `Partitioning`, `PartitioningFactory`, or `NULL`
 #' @section Methods:
 #'
 #' A `Dataset` has the following methods:
@@ -268,11 +268,9 @@ DatasetFactory <- R6Class("DatasetFactory", inherit = ArrowObject,
   )
 )
 DatasetFactory$create <- function(x,
-                                  filesystem = c("auto", "local"),
-                                  format = c("parquet", "arrow", "ipc", "feather"),
+                                  filesystem = NULL,
+                                  format = c("parquet", "arrow", "ipc", "feather", "csv", "tsv", "text"),
                                   partitioning = NULL,
-                                  allow_not_found = FALSE,
-                                  recursive = TRUE,
                                   ...) {
   if (is_list_of(x, "DatasetFactory")) {
     return(shared_ptr(DatasetFactory, dataset___UnionDatasetFactory__Make(x)))
@@ -282,24 +280,18 @@ DatasetFactory$create <- function(x,
   }
 
   if (!inherits(filesystem, "FileSystem")) {
-    filesystem <- match.arg(filesystem)
-    if (filesystem == "auto") {
-      # When there are other FileSystems supported, detect e.g. S3 from x
-      filesystem <- "local"
+    if (grepl("://", x)) {
+      fs_from_uri <- FileSystem$from_uri(x)
+      filesystem <- fs_from_uri$fs
+      x <- fs_from_uri$path
+    } else {
+      filesystem <- LocalFileSystem$create()
     }
-    filesystem <- list(
-      local = LocalFileSystem
-      # We'll register other file systems here
-    )[[filesystem]]$create(...)
   }
-  selector <- FileSelector$create(
-    x,
-    allow_not_found = allow_not_found,
-    recursive = recursive
-  )
+  selector <- FileSelector$create(x, allow_not_found = FALSE, recursive = TRUE)
 
   if (is.character(format)) {
-    format <- FileFormat$create(match.arg(format))
+    format <- FileFormat$create(match.arg(format), ...)
   } else {
     assert_is(format, "FileFormat")
   }
@@ -331,11 +323,19 @@ DatasetFactory$create <- function(x,
 #' a list of `DatasetFactory` objects whose datasets should be
 #' grouped. If this argument is specified it will be used to construct a
 #' `UnionDatasetFactory` and other arguments will be ignored.
-#' @param filesystem A string identifier for the filesystem corresponding to
-#' `x`. Currently only "local" is supported.
-#' @param format A string identifier of the format of the files in `x`.
-#' Currently "parquet" and "ipc"/"arrow"/"feather" (aliases for each other)
-#' are supported. For Feather, only version 2 files are supported.
+#' @param filesystem A [FileSystem] object; if omitted, the `FileSystem` will
+#' be detected from `x`
+#' @param format A [FileFormat] object, or a string identifier of the format of
+#' the files in `x`. Currently supported values:
+#' * "parquet"
+#' * "ipc"/"arrow"/"feather", all aliases for each other; for Feather, note that
+#'   only version 2 files are supported
+#' * "csv"/"text", aliases for the same thing (because comma is the default
+#'   delimiter for text files
+#' * "tsv", equivalent to passing `format = "text", delimiter = "\t"`
+#'
+#' Default is "parquet", unless a `delimiter` is also specified, in which case
+#' it is assumed to be "text".
 #' @param partitioning One of
 #'   * A `Schema`, in which case the file paths relative to `sources` will be
 #'    parsed, and path segments will be matched with the schema fields. For
@@ -348,11 +348,10 @@ DatasetFactory$create <- function(x,
 #'    by [hive_partition()] which parses explicit or autodetected fields from
 #'    Hive-style path segments
 #'   * `NULL` for no partitioning
-#' @param allow_not_found logical: is `x` allowed to not exist? Default
-#' `FALSE`. See [FileSelector].
-#' @param recursive logical: should files be discovered in subdirectories of
-#' `x`? Default `TRUE`.
-#' @param ... Additional arguments passed to the [FileSystem] `$create()` method
+#' @param ... Additional format-specific options, passed to
+#' `FileFormat$create()`. For CSV options, note that you can specify them either
+#' with the Arrow C++ library naming ("delimiter", "quoting", etc.) or the
+#' `readr`-style naming used in [read_csv_arrow()] ("delim", "quote", etc.)
 #' @return A `DatasetFactory` object. Pass this to [open_dataset()],
 #' in a list potentially with other `DatasetFactory` objects, to create
 #' a `Dataset`.
@@ -399,17 +398,26 @@ FileSystemDatasetFactory$create <- function(filesystem,
 #'
 #' @section Factory:
 #' `FileFormat$create()` takes the following arguments:
-#' * `format`: A string identifier of the format of the files in `path`.
-#'   Currently "parquet" and "ipc"/"arrow"/"feather" (aliases for each other)
-#'   are supported. For Feather, only version 2 files are supported.
+#' * `format`: A string identifier of the file format. Currently supported values:
+#'   * "parquet"
+#'   * "ipc"/"arrow"/"feather", all aliases for each other; for Feather, note that
+#'     only version 2 files are supported
+#'   * "csv"/"text", aliases for the same thing (because comma is the default
+#'     delimiter for text files
+#'   * "tsv", equivalent to passing `format = "text", delimiter = "\t"`
 #' * `...`: Additional format-specific options
-#'   format="parquet":
+#'
+#'   `format = "parquet"``:
 #'   * `use_buffered_stream`: Read files through buffered input streams rather than
 #'                            loading entire row groups at once. This may be enabled
 #'                            to reduce memory overhead. Disabled by default.
 #'   * `buffer_size`: Size of buffered stream, if enabled. Default is 8KB.
 #'   * `dict_columns`: Names of columns which should be read as dictionaries.
 #'
+#'   `format = "text"`: see [CsvReadOptions]. Note that you can specify them either
+#'   with the Arrow C++ library naming ("delimiter", "quoting", etc.) or the
+#'   `readr`-style naming used in [read_csv_arrow()] ("delim", "quote", etc.)
+#'
 #' It returns the appropriate subclass of `FileFormat` (e.g. `ParquetFileFormat`)
 #' @rdname FileFormat
 #' @name FileFormat
@@ -422,6 +430,8 @@ FileFormat <- R6Class("FileFormat", inherit = ArrowObject,
         shared_ptr(ParquetFileFormat, self$pointer())
       } else if (type == "ipc") {
         shared_ptr(IpcFileFormat, self$pointer())
+      } else if (type == "csv") {
+        shared_ptr(CsvFileFormat, self$pointer())
       } else {
         self
       }
@@ -434,7 +444,12 @@ FileFormat <- R6Class("FileFormat", inherit = ArrowObject,
   )
 )
 FileFormat$create <- function(format, ...) {
-  if (format == "parquet") {
+  opt_names <- names(list(...))
+  if (format %in% c("csv", "text") || any(opt_names %in% c("delim", "delimiter"))) {
+    CsvFileFormat$create(...)
+  } else if (format == c("tsv")) {
+    CsvFileFormat$create(delimiter = "\t", ...)
+  } else if (format == "parquet") {
     ParquetFileFormat$create(...)
   } else if (format %in% c("ipc", "arrow", "feather")) { # These are aliases for the same thing
     shared_ptr(IpcFileFormat, dataset___IpcFileFormat__Make())
@@ -461,6 +476,25 @@ ParquetFileFormat$create <- function(use_buffered_stream = FALSE,
 #' @export
 IpcFileFormat <- R6Class("IpcFileFormat", inherit = FileFormat)
 
+#' @usage NULL
+#' @format NULL
+#' @rdname FileFormat
+#' @export
+CsvFileFormat <- R6Class("CsvFileFormat", inherit = FileFormat)
+CsvFileFormat$create <- function(..., opts = csv_file_format_parse_options(...)) {
+  shared_ptr(CsvFileFormat, dataset___CsvFileFormat__Make(opts))
+}
+
+csv_file_format_parse_options <- function(...) {
+  # Support both the readr spelling of options and the arrow spelling
+  readr_opts <- c("delim", "quote", "escape_double", "escape_backslash", "skip_empty_rows")
+  if (any(readr_opts %in% names(list(...)))) {
+    readr_to_csv_parse_options(...)
+  } else {
+    CsvParseOptions$create(...)
+  }
+}
+
 #' Scan the contents of a dataset
 #'
 #' @description
