@@ -39,16 +39,15 @@ test_that("Schema print method", {
   )
 })
 
-test_that("Schema $metadata when there is none", {
-  expect_null(schema(b = double())$metadata)
-})
-
 test_that("Schema $GetFieldByName", {
   schm <- schema(b = double(), c = string())
   expect_equal(schm$GetFieldByName("b"), field("b", double()))
   expect_null(schm$GetFieldByName("f"))
   # TODO: schema(b = double(), b = string())$GetFieldByName("b")
   # also returns NULL and probably should error bc duplicated names
+
+  expect_equal(schm$b, field("b", double()))
+  expect_equal(schm[["b"]], field("b", double()))
 })
 
 test_that("reading schema from Buffer", {
@@ -82,7 +81,7 @@ test_that("reading schema from Buffer", {
 test_that("Input validation when creating a table with a schema", {
   expect_error(
     Table$create(b = 1, schema = c(b = float64())), # list not Schema
-    "schema must be an arrow::Schema or NULL"
+    "`schema` must be an arrow::Schema or NULL"
   )
 })
 
